function [x]=mortg_ballon_fixed(PH,XHI,RM,IBP)
% ------------------------------------------------------------------
% This program computes a combined BALLON + FIXED MORTGAGE
%  
%  1) Only interest payments until due date
%  2) Principal is paid in period M
%
% INPUT VARIABLES
% PH      = Price of square feet of housing
% XHI     = Number of square feet dwelling
% RM      = Mortgage interest rate
% IBP     = Number of periods to pay off the mortgage
%
% OUTPUT VARIABLES
% XPRIN   = Remaining principle in the loan
% XMPAY   = Mortgage payments
% XMD     = Interest deduction
% ------------------------------------------------------------------
% DEFINES MORTGAGE PARAMETERS
D     = 0.10;                        % Downpayment 
M     = 10;                          % Total length of the mortgage
MB    = 4;                           % Length of the balloon contract
MF    = M - MB;                      % Length of the fixed contract
XLOAN = (1.0-D)*PH*XHI;              % Loan size

if (IBP>1)
    
% BALLOON CONTRACT PART    
    if (IBP>MF+1)
    
        % COMPUTE THE INTEREST RATE PAYMENTS AND THE MORTGAGE DEDUCTION
        XIPAY = XLOAN*RM;            % Interest payments
        XMPAY = XIPAY;               % Mortgage payment=Interest payment
        RPRIN = XLOAN;               % Outstanding Principal= LOAN SIZE
        XMD   = XIPAY;               % Mortgage deduction

        x(1) = XMPAY;
        x(2) = XIPAY;
        x(3) = RPRIN;
        x(4) = XMD;
        
% FIXED TERM CONTRACT PART        
    elseif (IBP<=MF+1)

        XMPAY = zeros(MF,1);         % Mortgage payment 
        PAY   = zeros(MF+1,1);       % Outstanding Principal
        XIPAY = zeros(MF,1);         % Interest mortgage payments
        PPAY  = zeros(MF,1);         % Principal mortgage payments
        PAY(1)= XLOAN;               % Outstanding Principal= LOAN SIZE
        XMPAY(1:MF,1)   = (XLOAN*RM)/(1.0-(1.0 + RM)^-MF); 
        
        % COMPUTE THE INTEREST RATE PAYMENTS AND THE MORTGAGE DEDUCTION
        for I=1:MF           
            XIPAY(I)  = PAY(I)*RM;
            PPAY(I)   = XMPAY(I) - XIPAY(I);
            PAY(I+1)  = PAY(I) - PPAY(I);
        end
     
        XMD      = XIPAY;             % Mortgage deduction primary mortgage 
        
        x(1) = XMPAY(MF-IBP+2);
        x(2) = XIPAY(MF-IBP+2);
        x(3) = PAY(MF-IBP+2);
        x(4) = XMD(MF-IBP+2);
    end
    
% MORTAGE HAS BEEN PAID OFF
else
     x = [0 0 0 0];
end    