function [x]=mortg_combo(PH,XHI,RM,IBP)
% ------------------------------------------------------------------
% This program computes the FRM COMBO LOAN
%
% INPUT VARIABLES
% PH      = Price of square feet of housing
% XHI     = Number of square feet dwelling
% RM      = Mortgage interest rate
% IBP     = Number of periods to pay off the mortgage
%
% OUTPUT VARIABLES
% RPRIN   = Remaining principle in the loan
% XMPAY   = Mortgage payments
% XMD     = Interest deduction
% ------------------------------------------------------------------
% DEFINES MORTGAGE PARAMETERS
D     = 0.10;                         % Percent downpayment  
DS    = 0.10;                         % Size secondary loan  
M     = 30;                           % Mortgage length primary loan
M2    = 30;                           % Mortgage length secondary loan  
PREM  = 0.00;                         % Premium secondary loan  
TAUY  = 0.0;                          % Mortgage deduction 

% INITIALIZE SOME VARIABLES
if (IBP>1)
    
    XMPAY  = zeros(M,1);              % Mortgage payment principal primary loan
    PAY    = zeros(M+1,1);            % Outstanding principal primary loan
    XIPAY  = zeros(M,1);              % Interest mortgage payments primary loan
    PPAY   = zeros(M,1);              % Principal mortgage payments primary loan
    XLOAN  = (1.0 -D -DS)*PH*XHI;     % Loan size primary loan
    PAY(1) = XLOAN;                   % Outstanding Principal = PRIMARY LOAN SIZE

    XMPAY2 = zeros(M,1);              % Mortgage payment principal primary loan    
    PAY2   = zeros(M+1,1);            % Outstanding principal secondary loan
    XIPAY2 = zeros(M,1);              % Interest mortgage payments secondary loan
    PPAY2  = zeros(M,1);              % Principal mortgage payments secondary loan
    XLOAN2 = DS*PH*XHI;               % Loan size secondary loan
    PAY2(1)= XLOAN2;                  % Outstanding secondary = SECONDARY LOAN SIZE

    
% COMPUTE AMORTIZATION TERMS BOTH LOANS
    XMPAY(1:M,1)   = (XLOAN*RM)/(1.0-(1.0 + RM)^-M); 
    XMPAY2(1:M2,1) = (XLOAN2*(RM + PREM))/(1.0-(1.0 + (RM + PREM))^-M2); 
    
% COMPUTE THE INTEREST RATE PAYMENTS AND THE MORTGAGE DEDUCTION BOTH LOANS
for I=1:M
    XIPAY(I)  = PAY(I)*RM;
    PPAY(I)   = XMPAY(I) - XIPAY(I);
    PAY(I+1)  = PAY(I) - PPAY(I);
end
for I=1:M2
    XIPAY2(I) = PAY2(I)*(RM + PREM);
    PPAY2(I)  = XMPAY2(I) - XIPAY2(I);
    PAY2(I+1) = PAY2(I) - PPAY2(I);
end

    XMD      = XIPAY*TAUY;             % Mortgage deduction primary mortgage
    XMD2     = XIPAY2*TAUY;            % Mortgage deduction primary mortgage
    XMPAYTOT = XMPAY + XMPAY2;         % Total payments mortgage payments
    YXIPTOT  = XIPAY + XIPAY2;         % Total interest paymentsd
    RPRINTOT = PAY + PAY2;             % Total remaining principle
    XMDTOT   = XMD + XMD2;             % Total interest deduction
   
% PICK THE MORTGAGE VALUES FOR A GIVEN IBP

x(1) = XMPAYTOT(M-IBP+2);
x(2) = YXIPTOT(M-IBP+2);
x(3) = RPRINTOT(M-IBP+2);
x(4) = XMDTOT(M-IBP+2);

else
  x = [0 0 0 0];  
end
