function [x]=mortg_combo1(PH,XHI,RM,IBP)
% ------------------------------------------------------------------
% This program computes the COMBO LOAN
%
% INPUT VARIABLES
% PH      = Price of square feet of housing
% XHI     = Number of square feet dwelling
% RM      = Mortgage interest rate
% IBP     = Number of periods to pay off the mortgage
%
% OUTPUT VARIABLES
% RPRIN   = Remaining principle in the loan
% XMPAY   = Mortgage payments
% XMD     = Interest deduction
% ------------------------------------------------------------------
% DEFINES MORTGAGE PARAMETERS
D     = 0.10;                         % Percent downpayment  
DS    = 0.10;                         % Size secondary loan  
M     = 10;                           % Mortgage length primary loan
M2    = 3;                            % Mortgage length secondary loan  
PREM  = 0.0078;                       % Premium secondary loan  
TAUY  = 0.0;                          % Mortgage deduction 

% INITIALIZE SOME VARIABLES
if (IBP>1)
    
    PAY    = zeros(M+1,1);            % Outstanding principal primary loan
    XIPAY  = zeros(M,1);              % Interest mortgage payments primary loan
    PPAY   = zeros(M,1);              % Principal mortgage payments primary loan
    XLOAN  = (1.0 -D -DS)*PH*XHI;     % Loan size primary loan
    PAY(1) = XLOAN;                   % Outstanding Principal = PRIMARY LOAN SIZE

    PAY2   = zeros(M+1,1);            % Outstanding principal secondary loan
    XIPAY2 = zeros(M,1);              % Interest mortgage payments secondary loan
    PPAY2  = zeros(M,1);              % Principal mortgage payments secondary loan
    XLOAN2 = DS*PH*XHI;               % Loan size secondary loan
    PAY2(1)= XLOAN2;                  % Outstanding secondary = SECONDARY LOAN SIZE

    
% COMPUTE AMORTIZATION TERMS BOTH LOANS
    XMPAY  = (XLOAN*RM)/(1.0-(1.0 + RM)^-M); 
    XMPAY2 = (XLOAN2*(RM + PREM))/(1.0-(1.0 + (RM + PREM))^-M2); 
    
% COMPUTE THE INTEREST RATE PAYMENTS AND THE MORTGAGE DEDUCTION BOTH LOANS
for I=1:M
    XIPAY(I)  = PAY(I)*RM;
    PPAY(I)   = XMPAY - XIPAY(I);
    PAY(I+1)  = (1.0 + RM)*PAY(I) - XMPAY;
end
for I=1:M2
    XIPAY2(I) = PAY2(I)*(RM + PREM);
    PPAY2(I)  = XMPAY2 - XIPAY2(I);
    PAY2(I+1) = (1.0 + (RM + PREM))*PAY2(I) - XMPAY2;
end

% CALCULATE THE REMAINING PRINCIPLE GIVEN IBP ON BOTH MORTGAGE 
    CUMPRIN  = 0.0;
    CUMPRIN2 = 0.0;
    
    for I=1:M-IBP+2
        CUMPRIN  = CUMPRIN  + PPAY(I);
        CUMPRIN2 = CUMPRIN2 + PPAY2(I);
    end
    
    RPRIN  = XLOAN - CUMPRIN;         % Remaining principle primary mortgage
    YXIP   = XIPAY(M-IBP+2);          % Interest mortgage payments primary mortgage
    XMD    = YXIP*TAUY;               % Mortgage deduction primary mortgage
    XMPAY  = XMPAY - XMD;             % Mortgage payment net of deduction primary mortgage

    if IBP>= M2+2
        RPRIN2 = XLOAN2 - CUMPRIN2;   % Remaining principle secondary mortgage
        YXIP2  = XIPAY2(M-IBP+2);     % Interest mortgage payments secondary mortgage
        XMD2   = YXIP2*TAUY;          % Mortgage deduction secondary mortgage
        XMPAY2 = XMPAY2 - XMD2;       % Mortgage payment net of deduction secondary mortgage
    else
        XMD2   = 0.0;                 % Mortgage deduction secondary mortgage
        RPRIN2 = 0.0;                 % Remaining principle secondary mortgage
        YXIP2  = 0.0;                 % Interest mortgage payments secondary mortgage
        XMPAY2 = 0.0;                 % Mortgage payment net of deduction secondary mortgage
    end
        
else
    XMD    = 0.0;
    RPRIN  = 0.0;
    YXIP   = 0.0;
    XMPAY  = 0.0;
    
    XMD2   = 0.0;
    RPRIN2 = 0.0;
    YXIP2  = 0.0;
    XMPAY2 = 0.0;
end    
    
XMPAYTOT = XMPAY + XMPAY2;
YXIPTOT  = YXIP + YXIP2;     
RPRINTOT = RPRIN + RPRIN2;
XMDTOT   = XMD + XMD2;

disp(['   ----------------------------------------------------------'])
disp(['              MORTGAGE STATISTICS                            '])
disp(['   ----------------------------------------------------------'])
disp(['   Size primary mortgage:                  ', num2str(XLOAN)])
disp(['   Mortgage payment primary mortgage:      ',num2str(XMPAY)])
disp(['   Interest payments primary mortgage:     ',num2str(YXIP)])
disp(['   Remaining principle primary mortgage:   ',num2str(RPRIN)])
disp(['   ----------------------------------------------------------'])    
disp(['   Size secondary mortgage:                ', num2str(XLOAN2)])
disp(['   Mortgage payment secondary mortgage:    ',num2str(XMPAY2)])
disp(['   Interest payments secondary mortgage:   ',num2str(YXIP2)])
disp(['   Remaining principle secondary mortgage: ',num2str(RPRIN2)])
disp(['   ----------------------------------------------------------'])
disp(['   Mortgage payment TOTAL mortgage:        ', num2str(XLOAN+XLOAN2)])
disp(['   Mortgage payment TOTAL mortgage:        ',num2str(XMPAYTOT)])
disp(['   Interest payments TOTAL mortgage:       ',num2str(YXIPTOT)])
disp(['   Remaining principle TOTAL mortgage:     ',num2str(RPRINTOT)])
disp(['   ----------------------------------------------------------'])

x = [XMPAYTOT,YXIPTOT,RPRINTOT,XMDTOT];