function [x]=mortg_const(PH,XHI,RM,IBP)
% ------------------------------------------------------------------
% This program computes MORTGAGE WITH CONSTANT AMORTIZATION TERMS
%  
%  1) Drecreasing mortgage payments
%  2) Constant amortization of principal
%  3) Decreasing interest payments
%
% INPUT VARIABLES
% PH      = Price of square feet of housing
% XHI     = Number of square feet dwelling
% RM      = Mortgage interest rate
% IBP     = Number of periods to pay off the mortgage
%
% OUTPUT VARIABLES
% XPRIN   = Remaining principle in the loan
% XMPAY   = Mortgage payments
% XMD     = Interest deduction
% ------------------------------------------------------------------
% DEFINES MORTGAGE PARAMETERS
D     = 0.10;
M     = 10;

% INITIALIZE SOME VARIABLES
if (IBP>1)
    
    PAY    = zeros(M+1,1);             % Outstanding Principal
    XIPAY  = zeros(M,1);               % Interest mortgage payments
    XMPAY  = zeros(M,1);               % Mortgage payments
    XLOAN  = (1.0-D)*PH*XHI;           % Loan size
    PAY(1) = XLOAN;                    % Outstanding Principal= LOAN SIZE
    
% COMPUTE AMORTIZATION TERMS
    PPAY   = XLOAN/M;                  % Constant pricincipal payment (amortization)
    
% COMPUTE THE INTEREST RATE PAYMENTS AND THE MORTGAGE DEDUCTION
for I=1:M
    XIPAY(I)  = PAY(I)*RM;
    XMPAY(I)  = PPAY + XIPAY(I);
    PAY(I+1)  = PAY(I) - PPAY;    
end
    XMD      = XIPAY;                  % Mortgage deduction primary mortgage
   
% CALCULATE THE REMAINING PRINCIPLE GIVEN IBP TO GO ON MORTGAGE 
    x(1) = XMPAY(M-IBP+2);
    x(2) = XIPAY(M-IBP+2);
    x(3) = PAY(M-IBP+2);
    x(4) = XMD(M-IBP+2);
else
    x = [0 0 0 0];
end    