function [x]=mortg_geogth(PH,XHI,RM,IBP)
% ------------------------------------------------------------------
% This program computes the STANDARD MORTGAGE CONTRACT with PAYMENTS 
% GROWING at a GEOMETRIC RATE
%  
%  1) Growing mortgage payments
%  2) Increasing principal payments as fraction of total payments
%  3) Decreasing interest payments as fraction of total payments
%
% INPUT VARIABLES
% PH      = Price of square feet of housing
% XHI     = Number of square feet dwelling
% RM      = Mortgage interest rate
% IBP     = Number of periods to pay off the mortgage
%
% OUTPUT VARIABLES
% XPRIN   = Remaining principle in the loan
% XMPAY   = Mortgage payments
% XMD     = Interest deduction
% ------------------------------------------------------------------
% DEFINES MORTGAGE PARAMETERS
D     = 0.10;                             % Downpayment requierement
M     = 10;                               % Length of the mortgage
GM    = -0.09;                             % Growth rate of mortgage payments

if (RM <= GM)   
    disp(' ')
    disp('   WARNING: Negative Mortgage Payments')
    disp('  ')
    disp('   CHECK: i)  Growth rate of payments (GM) it too HIGH')
    disp('          ii) Mortgage interest rate (RM) it too LOW  ')
else    
% INITIALIZE SOME VARIABLES
    if (IBP>1)
    
        PAY   = zeros(M+1,1);             % Outstanding Principal
        XMPAY = zeros(M,1);               % Mortgage payments
        XIPAY = zeros(M,1);               % Interest mortgage payments
        PPAY  = zeros(M,1);               % Principal mortgage payments
        XLOAN = (1.0-D)*PH*XHI;           % Loan size       
    
% COMPUTE AMORTIZATION TERMS
        PAY(1)   = XLOAN;                 % Outstanding Principal= LOAN SIZE
        XMPAY(1) = XLOAN*((RM-GM)/(1.0-(1+GM)^M*(1+RM)^-M)); 
         
        for I=1:M-1
            XMPAY(I+1) = (1.0 + GM)^(I)*XMPAY(1);
        end
        
% COMPUTE THE INTEREST RATE PAYMENTS AND THE MORTGAGE DEDUCTION
        for I=1:M
            XIPAY(I)  = PAY(I)*RM;
            PPAY(I)   = XMPAY(I) - XIPAY(I);
            PAY(I+1)  = (1.0 + RM)*PAY(I) - XMPAY(I);
        end

        XMD = XIPAY;             % Mortgage deduction primary mortgage

% CALCULATE THE REMAINING PRINCIPLE GIVEN IBP TO GO ON MORTGAGE 
        x(1) = XMPAY(M-IBP+2);
        x(2) = XIPAY(M-IBP+2);
        x(3) = PAY(M-IBP+2);
        x(4) = XMD(M-IBP+2);

        else
        x = [0 0 0 0];
        end            
end