function [x]=mortg_ins(PH,XHI,RM,IBP)
% ------------------------------------------------------------------
% This program computes the FRM with PMI
%
% INPUT VARIABLES
% PH      = Price of square feet of housing
% XHI     = Number of square feet dwelling
% RM      = Mortgage interest rate
% IBP     = Number of periods to pay off the mortgage
%
% OUTPUT VARIABLES
% RPRIN   = Remaining principle in the loan
% XMPAY   = Mortgage payments
% XMD     = Interest deduction
% ------------------------------------------------------------------
% DEFINES MORTGAGE PARAMETERS
D     = 0.10;                         % Percent downpayment  
M     = 30;                           % Mortgage length  
TAUY  = 0.0;                          % Mortgage deduction 
PREM  = 0.0078;                       % PMI Mortgage insurance

% INITIALIZE SOME VARIABLES
if (IBP>1)

    XMPAY  = zeros(M,1);              % Mortgage payment   
    PAY   = zeros(M+1,1);             % Outstanding Principal
    XIPAY = zeros(M,1);               % Interest mortgage payments
    PPAY  = zeros(M,1);               % Principal mortgage payments
    XLOAN = (1.0-D)*PH*XHI;           % Loan size
    PAY(1) = XLOAN;                   % Outstanding Principal = LOAN SIZE
    
% COMPUTE AMORTIZATION TERMS AND MORTGAGE PREMIUM
    XMPAY(1:M,1) = (XLOAN*RM)/(1.0-(1.0 + RM)^-M); 
    XPREM        =  PREM*XLOAN;
    
% COMPUTE THE INTEREST RATE PAYMENTS AND THE MORTGAGE DEDUCTION
for I=1:M
    XIPAY(I)  = PAY(I)*RM;
    PPAY(I)   = XMPAY(I) - XIPAY(I);
    PAY(I+1)  = PAY(I) - PPAY(I);
end

    XMD      = XIPAY*TAUY;             % Mortgage deduction primary mortgage

% COMPUTE LOAN TO VALUE RATIO (LVR)
    LVR = PAY./(PH*XHI);

% CALCULATE THE REMAINING PRINCIPLE GIVEN IBP TO GO ON MORTGAGE 

    if LVR(M-IBP+2)>=0.78
       x(1)   = (XMPAY(M-IBP+2) + XPREM);
    else
       x(1)   =  XMPAY(M-IBP+2);
    end
    
    x(2) = XIPAY(M-IBP+2);
    x(3) = PAY(M-IBP+2);
    x(4) = XMD(M-IBP+2);

else
     x = [0 0 0 0];
end       
